#  Licensed to the Apache Software Foundation (ASF) under one
#  or more contributor license agreements.  See the NOTICE file
#  distributed with this work for additional information
#  regarding copyright ownership.  The ASF licenses this file
#  to you under the Apache License, Version 2.0 (the
#  "License"); you may not use this file except in compliance
#  with the License.  You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing,
#  software distributed under the License is distributed on an
#  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
#  KIND, either express or implied.  See the License for the
#  specific language governing permissions and limitations
#  under the License.

import abc

import attr

from sedona.utils.meta import MultipleMeta


@attr.s
class GeoDataReader(metaclass=MultipleMeta):

    @abc.abstractmethod
    def readToGeometryRDD(cls, *args, **kwargs):
        raise NotImplementedError(
            f"Instance of the class {cls.__class__.__name__} has to implement method readToGeometryRDD"
        )
